==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkImageAppend.java <==
// java wrapper for vtkImageAppend object
//

package vtk;
import vtk.*;

public class vtkImageAppend extends vtkThreadedImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ReplaceNthInputConnection_2(int id0,vtkAlgorithmOutput id1);
  public void ReplaceNthInputConnection(int id0,vtkAlgorithmOutput id1)
    { ReplaceNthInputConnection_2(id0,id1); }

  private native void SetInputData_3(int id0,vtkDataObject id1);
  public void SetInputData(int id0,vtkDataObject id1)
    { SetInputData_3(id0,id1); }

  private native void SetInputData_4(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_4(id0); }

  private native long GetInput_5(int id0);
  public vtkDataObject GetInput(int id0) {
    long temp = GetInput_5(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_6();
  public vtkDataObject GetInput() {
    long temp = GetInput_6();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfInputs_7();
  public int GetNumberOfInputs()
    { return GetNumberOfInputs_7(); }

  private native void SetAppendAxis_8(int id0);
  public void SetAppendAxis(int id0)
    { SetAppendAxis_8(id0); }

  private native int GetAppendAxis_9();
  public int GetAppendAxis()
    { return GetAppendAxis_9(); }

  private native void SetPreserveExtents_10(int id0);
  public void SetPreserveExtents(int id0)
    { SetPreserveExtents_10(id0); }

  private native int GetPreserveExtents_11();
  public int GetPreserveExtents()
    { return GetPreserveExtents_11(); }

  private native void PreserveExtentsOn_12();
  public void PreserveExtentsOn()
    { PreserveExtentsOn_12(); }

  private native void PreserveExtentsOff_13();
  public void PreserveExtentsOff()
    { PreserveExtentsOff_13(); }

  public vtkImageAppend() { super(); }

  public vtkImageAppend(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkImageAppend.java <==
// java wrapper for vtkImageAppend object
//

package vtk;
import vtk.*;

public class vtkImageAppend extends vtkThreadedImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ReplaceNthInputConnection_2(int id0,vtkAlgorithmOutput id1);
  public void ReplaceNthInputConnection(int id0,vtkAlgorithmOutput id1)
    { ReplaceNthInputConnection_2(id0,id1); }

  private native void SetInputData_3(int id0,vtkDataObject id1);
  public void SetInputData(int id0,vtkDataObject id1)
    { SetInputData_3(id0,id1); }

  private native void SetInputData_4(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_4(id0); }

  private native long GetInput_5(int id0);
  public vtkDataObject GetInput(int id0) {
    long temp = GetInput_5(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_6();
  public vtkDataObject GetInput() {
    long temp = GetInput_6();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfInputs_7();
  public int GetNumberOfInputs()
    { return GetNumberOfInputs_7(); }

  private native void SetAppendAxis_8(int id0);
  public void SetAppendAxis(int id0)
    { SetAppendAxis_8(id0); }

  private native int GetAppendAxis_9();
  public int GetAppendAxis()
    { return GetAppendAxis_9(); }

  private native void SetPreserveExtents_10(int id0);
  public void SetPreserveExtents(int id0)
    { SetPreserveExtents_10(id0); }

  private native int GetPreserveExtents_11();
  public int GetPreserveExtents()
    { return GetPreserveExtents_11(); }

  private native void PreserveExtentsOn_12();
  public void PreserveExtentsOn()
    { PreserveExtentsOn_12(); }

  private native void PreserveExtentsOff_13();
  public void PreserveExtentsOff()
    { PreserveExtentsOff_13(); }

  public vtkImageAppend() { super(); }

  public vtkImageAppend(long id) { super(id); }
  public native long   VTKInit();

}
